'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var debounce = require('debounce');

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return;
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var useDevice = function useDevice() {
  var breakpoints = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
    tablet: 700,
    desktop: 1200
  };

  var _useState = react.useState(window.innerWidth < breakpoints.tablet),
      _useState2 = _slicedToArray(_useState, 2),
      isMobile = _useState2[0],
      setMobile = _useState2[1];

  var _useState3 = react.useState(window.innerWidth >= breakpoints.tablet && window.innerWidth < breakpoints.desktop),
      _useState4 = _slicedToArray(_useState3, 2),
      isTablet = _useState4[0],
      setTablet = _useState4[1];

  var _useState5 = react.useState(window.innerWidth >= breakpoints.desktop),
      _useState6 = _slicedToArray(_useState5, 2),
      isDesktop = _useState6[0],
      setDesktop = _useState6[1];

  react.useLayoutEffect(function () {
    var handleResize = function handleResize() {
      setMobile(window.innerWidth < breakpoints.tablet);
      setTablet(window.innerWidth >= breakpoints.tablet && window.innerWidth < breakpoints.desktop);
      setDesktop(window.innerWidth >= breakpoints.desktop);
    };

    var debounced = debounce.debounce(handleResize, 100);
    window.addEventListener("resize", debounced);
    return function () {
      window.removeEventListener("resize", debounced);
    };
  }, [breakpoints]);
  return {
    isMobile: isMobile,
    isTablet: isTablet,
    isDesktop: isDesktop
  };
};

exports.useDevice = useDevice;
//# sourceMappingURL=index.js.map
